@@ -25,6 +25,10 @@ keywords = {
     "INPUT": "INPUT",
     "点击": "CLICK",
     "CLICK": "CLICK",
+    "右击": "RIGHT_CLICK",
+    "RIGHT_CLICK": "RIGHT_CLICK",
+    "双击":"DOUBLE_CLICK",
+    "DOUBLE_CLICK":"DOUBLE_CLICK",
     "关闭": "CLOSE",
     "CLOSE": "CLOSE",
     "清除": "CLEAR",
