@@ -3,7 +3,7 @@
 # @time 2020/8/22 18:27
 
 
-from common.utility import Excel, element_format
+from sktest.common.utility import Excel, element_format
 
 
 class Elements:
@@ -14,7 +14,6 @@ class Elements:
     def get_elements(self, elements_file):
         e = Excel(elements_file)
         self.elements = element_format(e.read('elements'))
-        # print(self.elements)
 
     def have(self, page, element):
         ele = page + '-' + element
@@ -22,7 +21,7 @@ class Elements:
             return ele
         else:
             """元素查不到"""
-            return ele
+            return ''
 
     def get(self, element):
         el_ = self.elements.get(element)
