@@ -2,16 +2,17 @@
 # @auth 小哥哥
 # @time 2020/8/24 8:58
 
+
+from time import sleep
+
 from selenium.webdriver.common.by import By
 from selenium.webdriver.support.ui import WebDriverWait
 from selenium.webdriver.support import expected_conditions as EC
 
-from common.config import element_wait_time
-from common.elements import el
-from common.globals import g
-from time import sleep
-
-from common.log import logger
+from sktest.common.config import element_wait_time
+from sktest.common.elements import el
+from sktest.common.globals import g
+from sktest.common.log import logger
 
 
 def locating_element(element):
