@@ -3,14 +3,14 @@
 # @time 2020/8/25 10:57
 
 
-import logging
 import sys
-from common.utility import get_today, mkdir, Path
+import logging
+from sktest.common.utility import get_today, mkdir_, Path
 
-mkdir('log')
+mkdir_('logs/'+get_today())
 logger = logging.getLogger('x')  # 实例化logger对象
 logger.setLevel(logging.INFO)  # 设置日志输出级别
-logfile = Path('log') / f"{get_today()}.log"  # 日志文件路径
+logfile = Path('logs/'+get_today()) / f"{get_today()}.log"  # 日志文件路径
 formatter = logging.Formatter('%(asctime)s [%(levelname)s]: #  %(message)s')  # 日志输出格式
 file_handle = logging.FileHandler(filename=logfile, encoding='utf8')
 # file_handle.setLevel(logging.INFO)
@@ -21,5 +21,3 @@ control_handle.setFormatter(formatter)
 logger.addHandler(file_handle)
 logger.addHandler(control_handle)
 
-if __name__ == '__main__':
-    print(mkdir('kkk'))
