@@ -23,6 +23,8 @@ def ocr_image(image_path):
             tb.append(1)
     image = image.point(tb, '1')
     code = tesserocr.image_to_text(image)
-    # print(code)
+    print(code)
     return code
 
+ocr_image("E:\TestDemo\cypress\screenshots\demo.js\Demo -- Demo.png")
+
