@@ -1,10 +1,12 @@
 # -*-coding:utf8-*-
 # @auth 小哥哥
 # @time 2020/8/27 10:35
+
+
 import os
 from datetime import datetime
-from common.utility import get_today,mkdir
-from common.globals import g
+from sktest.common.utility import get_today, mkdir_
+from sktest.common.globals import g
 
 
 def snapshot(img_file, element=None, ):
@@ -17,6 +19,6 @@ def snapshot(img_file, element=None, ):
     if element:
         result = element.screenshot('snapshot/' + str(img_file))
         return result
-    path = mkdir(os.path.join("D:/sktest/snapshot", get_today()))
+    path = mkdir_(os.path.join("snapshot/" + get_today()))
     result = g.driver.save_screenshot(path + '/' + datetime.strftime(datetime.now(), '%H%M%S') + '_' + img_file)
     return result
